self.__BUILD_MANIFEST=function(s,c,e,a,t,u,i,n,f,j,r,o,b,k){return{__rewrites:{afterFiles:[],beforeFiles:[],fallback:[]},"/":["static/chunks/pages/index-444f1804401f04ea.js"],"/_error":["static/chunks/pages/_error-c66a4e8afc46f17b.js"],"/clusters":["static/chunks/pages/clusters-50f39547341fc1dd.js"],"/clusters/[cluster]":[s,a,f,j,t,c,e,r,u,o,i,b,k,"static/chunks/1871-7e44247be8846c6f.js","static/chunks/pages/clusters/[cluster]-24796e5ff840869b.js"],"/clusters/[cluster]/[job]":[s,c,u,n,"static/chunks/pages/clusters/[cluster]/[job]-00a6804077e77339.js"],"/config":["static/chunks/pages/config-73d55faf3579201c.js"],"/infra":["static/chunks/pages/infra-0f1b3fc573e48680.js"],"/infra/[context]":["static/chunks/pages/infra/[context]-a18b2b3be108924d.js"],"/jobs":["static/chunks/pages/jobs-32a2329c2c7924da.js"],"/jobs/pools/[pool]":[s,a,t,"static/chunks/8821-93c25df904a8362b.js",c,e,i,"static/chunks/pages/jobs/pools/[pool]-23c18d2f1bb50770.js"],"/jobs/[job]":[s,a,t,c,e,n,"static/chunks/pages/jobs/[job]-cccd4084368465e5.js"],"/jobs/[job]/[task]":[s,c,e,n,"static/chunks/pages/jobs/[job]/[task]-15f57cd6d2efc78e.js"],"/plugins/[...slug]":[s,"static/chunks/pages/plugins/[...slug]-d107bfb150f3ff47.js"],"/recipes":["static/chunks/pages/recipes-fe8f0e2a270f193f.js"],"/recipes/[recipe]":["static/chunks/pages/recipes/[recipe]-e7e182d8e90bba06.js"],"/users":["static/chunks/pages/users-4cb4094a49eaf855.js"],"/volumes":["static/chunks/pages/volumes-0b175e9d3e330403.js"],"/workspace/new":["static/chunks/pages/workspace/new-7ab184ccd079eaaa.js"],"/workspaces":["static/chunks/pages/workspaces-e636ccc3eae09779.js"],"/workspaces/[name]":[s,a,f,j,c,e,r,u,o,i,b,k,"static/chunks/8050-4ce701cad6d9a965.js","static/chunks/pages/workspaces/[name]-fc08d4c8088628c7.js"],sortedPages:["/","/_app","/_error","/clusters","/clusters/[cluster]","/clusters/[cluster]/[job]","/config","/infra","/infra/[context]","/jobs","/jobs/pools/[pool]","/jobs/[job]","/jobs/[job]/[task]","/plugins/[...slug]","/recipes","/recipes/[recipe]","/users","/volumes","/workspace/new","/workspaces","/workspaces/[name]"]}}("static/chunks/5739-d67458fcb1386c92.js","static/chunks/3850-07bf3d8e993697da.js","static/chunks/9224-ce4921527754ed7b.js","static/chunks/1272-1ef0bf0237faccdb.js","static/chunks/1417-b0a44cc81ad11e8c.js","static/chunks/1676-a886dd6f2496a0ef.js","static/chunks/7248-5700883c888fee63.js","static/chunks/6612-187855dba2b299a7.js","static/chunks/6082-edabd8f6092300ce.js","static/chunks/1051-3f41c1235ec47f40.js","static/chunks/6990-3bd9cfff076cb071.js","static/chunks/1043-6176adbeddcbd855.js","static/chunks/9353-df1cc0bf94fc39a6.js","static/chunks/9243-c93651f5056787b2.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();